/***************************************************************************
 **     I2C_UEBER-LIB Test Program
 **
 **     Provides a simple test of an TMP101 temperature sensor connected to I2C1
 **     (Use a debugger to verify result. No USART is setup)
 **
 **     Used with ATOLLIC C/C++ Compiler Version 2.2.1
 **
 **		Based and depends on ST Peripheral LIB V3.5.0
 **
 **		Date: February 21, 2012, GJO
 **
 **		This program can be used freely and is in the public domain
 **
 ***************************************************************************/

/*
	Usage Notes:

	1) Make sure #include "stm32f10x_i2c.h"  in stm32f10x_conf.h is uncommented
	2) Use 2K pullup resistors on SDA and SCL lines
	3) Connect TMP101 to I2C1 bus lines (PB6=SCL1, PB7=SDA1)
	4) I2C1 uses I2C Peripheral 1 using PB6 and PB7 pins
	5) I2C2 uses I2C Peripheral 2 using PB10 and PB11 pins
	6) Target CPU for testing was STM32F103VE running at 72MHz
	7) Build variables must be setup as: STM32F10X_HD and USE_STDPERIPH_DRIVER
	9) This program has been tested to run properly on a STM32F103VE based hardware
	10) For the STDPERIPH library to work as expected make sure the following
	    ENVIRONMENT VARIABLES are incorporated in your tool chain with a HD device:

		"STM32F10X_HD"
		"USE_STDPERIPH_DRIVER"
	11) This test program builds completely error and warning free under Atollic V2.2.1
	12) Edit system_stm32f10.c for MCU clock speed options
	13) This test program runs at 72MHz.

*/

#include "stm32f10x.h"
#include "I2C_UeberLib.h"

void write_TMP101(I2C_TypeDef* I2Cx, u8);
s16 read_TMP101(I2C_TypeDef* I2Cx, u8);

// TMP101 defines:
#define TMP101_SLAVE_ADR_WSPT 	0x94


/**
 * @brief
 * @param
 * @retval
 */
void write_TMP101(I2C_TypeDef* I2Cx, u8 address)
{
	i2c_start(I2Cx);
	// Check for timeout to detect missing or malfunctioning sensor
	if(!i2c_write7bitAddress(I2Cx, address, I2C_DIR_TX))
	{
		i2c_write(I2Cx, 0x01);   // Configuration register selected
		i2c_write(I2Cx, 0x60);   // 12 bit continuous mode selected
	}
	i2c_stop(I2Cx);

}


/**
 * @brief  Reads current TMP101 temperature value
 * @param  pointer to I2C bus, TMP101 slave address
 * @retval s16 tmp101 result divided by 16
 */
s16 read_TMP101(I2C_TypeDef* I2Cx, u8 address)
{
	s16 result = -15984; // Error return value for no sensor found (-62.4 DEGC)

    i2c_start(I2Cx);
	// Check for timeout to detect missing or malfunctioning sensor
	if(!i2c_write7bitAddress(I2Cx, address, I2C_DIR_TX))
	{
		i2c_write(I2Cx, 0x00);      // Configuration register = read temperature
		i2c_start(I2Cx);
		i2c_write7bitAddress(I2Cx, address, I2C_DIR_RX);     // Enable read mode

		// Read MSB/LSB data from TMP101 and assemble output word
		result = (s16) i2c_read(I2Cx, ACK) << 8;
		result += (s16) i2c_read(I2Cx, ACK);
		i2c_stop(I2Cx);
	}
	else
	{
		i2c_stop(I2Cx);
	}
	return(result);
}



int main(void)
{
	s16 reading=0;

	// Note: In Atollic all system setup is done already before "main()"

	// Initializes the I2C peripherals and used GPIO pins
	I2C1_I2C2_BUS_Init();
	// Configures TMP101 for 12-bit resolution
	write_TMP101(I2C1, TMP101_SLAVE_ADR_WSPT);
	// Read the most current temperature value. Divide result by 256 to get DEG C
	// At room temperature a typical value should be around 5800
	// A reading of -15984 indicates a I2C Bus issue or faulty sensor
	reading = read_TMP101(I2C1, TMP101_SLAVE_ADR_WSPT);
	// Wait here forever
	while(1);

}
